<?php
/**
 * Theme Framework functions and definitions
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, @link http://codex.wordpress.org/Plugin_API
 *
 * @package CMSSuperHeroes
 * @subpackage CMS Theme
 * @since 1.0.0
 */

/**
 * Add global values.
 */
/* Dismiss vc update. */
if(function_exists('vc_set_as_theme')) vc_set_as_theme( true );

/* Add base functions */
function garden_get_global_base() {
	global $garden_base;

	if(!class_exists("GardenBase")){
    	require( get_template_directory() . '/inc/base.class.php' );
	}

	$garden_base = new GardenBase;
}
garden_get_global_base();

/* Add ReduxFramework. */
if(!class_exists('ReduxFramework')){
    require( get_template_directory() . '/inc/ReduxCore/framework.php' );
}

/* Add theme options. */
require( get_template_directory() . '/inc/options/functions.php' );

/**
 * Add new elements for VC
 * 
 * @author FOX
 */
add_action('vc_before_init', 'garden_vc_before');
	function garden_vc_before(){
    
    	if(!class_exists('CmsShortCode'))
        
        return ;
    
    	require( get_template_directory() . '/vc_params/vc_custom_heading.php' );
        require( get_template_directory() . '/vc_params/vc_raw_html.php' );
        require( get_template_directory() . '/vc_params/vc_btn.php' );
        require( get_template_directory() . '/vc_params/vc_column_text.php' );
        require( get_template_directory() . '/vc_params/vc_rows.php' );
        require( get_template_directory() . '/vc_params/vc_single_image.php' );
	}
/**
 * Custom params & remove VC Elements.
 * 
 * @author FOX
 */
add_action('vc_after_init', 'garden_vc_after');
	function garden_vc_after() {
    
    	//require( get_template_directory() . '/vc_params/vc_rows.php' );
	}

//Add widget


require( get_template_directory() . '/inc/widgets/recent_post_v2.php' );

/* Add SCSS */
if(!class_exists('scssc')){
    require( get_template_directory() . '/inc/libs/scss.inc.php' );
}

	require( get_template_directory() . '/inc/widgets/social.php' );

/* Add Meta Core Options */
if(is_admin()){
    
    if(!class_exists('CsCoreControl')){
        /* add mete core */
        require( get_template_directory() . '/inc/metacore/core.options.php' );
        /* add meta options */
        require( get_template_directory() . '/inc/options/meta.options.php' );
    }
    
    /* tmp plugins. */
    require( get_template_directory() . '/inc/options/require.plugins.php' );
}

/* Add Template functions */
require( get_template_directory() . '/inc/template.functions.php' );

/* Static css. */
require( get_template_directory() . '/inc/dynamic/static.css.php' );

/* Dynamic css*/
require( get_template_directory() . '/inc/dynamic/dynamic.css.php' );

/* Add mega menu */
if(!class_exists('HeroMenuWalker') && isset($smof_data['menu_mega']) && ($smof_data['menu_mega'] == 1) ){
    
    require( get_template_directory() . '/inc/megamenu/mega-menu.php' );
}

// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 625;

/**
 * CMS Theme setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * CMS Theme supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since 1.0.0
 */

/* Include CMS shortcode */
	add_filter('cms-shorcode-list', 'garden_shortcodes_list');
		function garden_shortcodes_list() {
			 $garden_shortcodes_list = array(
			  'cms_carousel',
			  'cms_grid',
			  'cms_fancybox_single',
			 );
		return $garden_shortcodes_list;
	}

function garden_setup() {
	/*
	 * Makes Twenty Twelve available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on Twenty Twelve, use a find and replace
	 * to change 'wp-garden' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'wp-garden' , get_template_directory() . '/languages' );

	// Adds title tag
	add_theme_support( "title-tag" );
	
	// Add woocommerce
	add_theme_support('woocommerce');
	
	// Adds custom header
	add_theme_support( 'custom-header' );
	
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'video', 'audio' , 'gallery', 'link', 'quote',) );

	// This theme uses wp_nav_menu() in one location.
	//register_nav_menu( 'primary', esc_html__( 'Primary Menu', 'wp-garden' ) );

	register_nav_menus( 
		array (
			'primary' => esc_html__( 'Primary Menu', 'wp-garden' ),
			'menu-footer' => esc_html__( 'Footer Menu', 'wp-garden' ),
		)
	);

	/*
	 * This theme supports custom background color and image,
	 * and here we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'e6e6e6',
	) );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	add_image_size('garden-size-img', 850, 500, true);
	add_image_size('garden-size-img-masonry', 800, 950, true);
	add_image_size('garden-size-img-sqr', 500, 500, true);
	add_image_size('garden-size-img-team', 500, 622, true);
	set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop
	
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}

add_action( 'after_setup_theme', 'garden_setup' );

/**
 * Add google font
 */
function garden_droid_serit_google_font() {
    $fonts_url = '';
    $droid_serif = _x( 'on', 'Droid Serif font: on or off', 'wp-garden' );
    if ( 'off' !== $droid_serif ) {
        $query_args = array(
	        'family' =>  'Droid+Serif:400,400italic,700,700italic', 
	        'subset' => urlencode( 'latin,latin-ext' )
        );
    }  
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

    return esc_url_raw( $fonts_url );
}

function garden_shadows_google_font() {
    $fonts_url = '';
    $shadows = _x( 'on', 'Shadows Into Light font: on or off', 'wp-garden' );
    if ( 'off' !== $shadows ) {
        $query_args = array(
	        'family' =>  'Shadows+Into+Light', 
	        'subset' => urlencode( 'latin,latin-ext' )
        );
    }  
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

    return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles for front-end.
 * @author Fox
 * @since CMS SuperHeroes 1.0
 */
function garden_scripts_styles() {
    
	global $smof_data, $wp_styles;
	
	/** theme options. */
	$script_options = array(
	    'menu_sticky'=> $smof_data['menu_sticky'],
	    'menu_sticky_tablets'=> $smof_data['menu_sticky_tablets'],
	    'menu_sticky_mobile'=> $smof_data['menu_sticky_mobile'],
	    'paralax' => 1,
	    'back_to_top'=> $smof_data['footer_botton_back_to_top']
	);

	/*------------------------------------- JavaScript ---------------------------------------*/
	
	
	/** --------------------------libs--------------------------------- */
	
	
	/* Adds JavaScript Bootstrap. */
	wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ), '3.3.2');
	
	/* Add parallax plugin. */
	wp_enqueue_script('parallax', get_template_directory_uri() . '/assets/js/jquery.parallax-1.1.3.js', array( 'jquery' ), '1.1.3', true);
	
	/* Add smoothscroll plugin */
	if($smof_data['smoothscroll']){
	   wp_enqueue_script('wp-garden-smoothscroll', get_template_directory_uri() . '/assets/js/smoothscroll.min.js', array( 'jquery' ), '1.0.0', true);
	}
	
	/** --------------------------custom------------------------------- */
	
	/* Add main.js */
	wp_register_script('wp-garden-main', get_template_directory_uri() . '/assets/js/main.js', array( 'jquery' ), '1.0.0', true);
	wp_localize_script('wp-garden-main', 'CMSOptions', $script_options);
	wp_enqueue_script('wp-garden-main');
	/* Add menu.js */
    wp_enqueue_script('wp-garden-menu', get_template_directory_uri() . '/assets/js/menu.js', array( 'jquery' ), '1.0.0', true);
    wp_enqueue_script('wp-garden-lightbox', get_template_directory_uri() . '/assets/js/lightbox-plus-jquery.js', array( 'jquery' ), '1.0.0', true);
	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

    /*------------------------------------- Stylesheet ---------------------------------------*/
	
	/** --------------------------libs--------------------------------- */
	wp_enqueue_style( 'wp-garden-droid-font', garden_droid_serit_google_font(), array(), null );
	wp_enqueue_style( 'wp-garden-shadows-font', garden_shadows_google_font(), array(), null );
	
	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', array(), '3.3.2');
	wp_enqueue_style('wp-garden-lightbox', get_template_directory_uri() . '/assets/css/lightbox.min.css', array(), '3.3.2');
	
	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('wp-garden-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), '4.3.0');

	/* Loads Font Ionicons. */
	wp_enqueue_style('wp-garden-font-ionicons', get_template_directory_uri() . '/assets/css/ionicons.min.css', array(), '2.0.1');

	/* Loads Pe Icon. */
	wp_enqueue_style('wp-garden-pe-icon', get_template_directory_uri() . '/assets/css/pe-icon-7-stroke.css', array(), '1.0.1');

	wp_enqueue_style('wp-garden-maintenance', get_template_directory_uri() . '/assets/css/maintenance.css', array(), '1.0.1');
	
	/** --------------------------custom------------------------------- */
	
	/* Loads our main stylesheet. */
	wp_enqueue_style( 'wp-garden-style', get_stylesheet_uri(), array( 'bootstrap' ));

	/* Loads the Internet Explorer specific stylesheet. */
	wp_enqueue_style( 'wp-garden-ie', get_template_directory_uri() . '/assets/css/ie.css', array( 'wp-garden-style' ), '20121010' );
	$wp_styles->add_data( 'wp-garden-ie', 'conditional', 'lt IE 9' );
	
	/* WooCommerce */
	if(class_exists('WooCommerce')){
	    require get_template_directory() . '/woocommerce/wc-template-hooks.php';
	    wp_enqueue_style( 'woocommerce', get_template_directory_uri() . "/assets/css/woocommerce.css", array(), '1.0.0');
	}
	
	/* Load static css*/
	wp_enqueue_style('wp-garden-static', get_template_directory_uri() . '/assets/css/static.css', array( 'wp-garden-style' ), '1.0.0');
}

add_action( 'wp_enqueue_scripts', 'garden_scripts_styles' );

/**
 * Register sidebars.
 *
 * Registers our main widget area and the front page widget areas.
 *
 * @since Fox
 */
function garden_widgets_init() {
	register_sidebar( array(
		'name' => esc_html__( 'Main Sidebar', 'wp-garden' ),
		'id' => 'main-sidebar',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wp-garden' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => esc_html__( 'Header Top Left', 'wp-garden' ),
		'id' => 'sidebar-top-left',
		'description' => esc_html__( 'Appears when using the optional Header with a page set as Header top left', 'wp-garden' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => esc_html__( 'Header Top Right', 'wp-garden' ),
		'id' => 'sidebar-top-right',
		'description' => esc_html__( 'Appears when using the optional Header with a page set as Header top right', 'wp-garden' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Form Menu', 'wp-garden' ),
    	'id' => 'form-menu',
    	'description' => esc_html__( 'Appears when using the optional Menu with a page set as Menu right', 'wp-garden' ),
    	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Footer Top 1', 'wp-garden' ),
    	'id' => 'sidebar-footer-top-1',
    	'description' => esc_html__( 'Appears when using the optional Footer with a page set as Footer Top 1', 'wp-garden' ),
    	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Footer Top 2', 'wp-garden' ),
    	'id' => 'sidebar-footer-top-2',
    	'description' => esc_html__( 'Appears when using the optional Footer with a page set as Footer Top 2', 'wp-garden' ),
    	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Footer Top 3', 'wp-garden' ),
    	'id' => 'sidebar-footer-top-3',
    	'description' => esc_html__( 'Appears when using the optional Footer with a page set as Footer Top 3', 'wp-garden' ),
    	'before_widget' => '<aside class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Footer Top 4', 'wp-garden' ),
    	'id' => 'sidebar-footer-top-4',
    	'description' => esc_html__( 'Appears when using the optional Footer with a page set as Footer Top 4', 'wp-garden' ),
    	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Footer Boton Left', 'wp-garden' ),
    	'id' => 'sidebar-bottom-left',
    	'description' => esc_html__( 'Appears when using the optional Footer Boton with a page set as Footer Boton left', 'wp-garden' ),
    	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
    	'name' => esc_html__( 'Footer Boton Right', 'wp-garden' ),
    	'id' => 'sidebar-bottom-right',
    	'description' => esc_html__( 'Appears when using the optional Footer Boton with a page set as Footer Boton right', 'wp-garden' ),
    	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    	'after_widget' => '</aside>',
    	'before_title' => '<h3 class="wg-title">',
    	'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => esc_html__( 'Woocommerce Sidebar', 'wp-garden' ),
		'id' => 'woocommerce_sidebar',
		'description' => esc_html__( 'woocommerce_sidebar widgets', 'wp-garden' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'garden_widgets_init' );

/**
 * Get meta data.
 * 
 * @param string $key
 * @param string $default
 */
function garden_get_post_meta($key, $default = '', $post_id = NULL){
	
	global $post;
	
	/* key null. */
	if(!$key) return $default;
	
	$key = '_cms_' . $key;

	/* set post ID */
	if ( class_exists('Woocommerce') && (is_shop() || is_woocommerce() ) ) {
        $post_id = woocommerce_get_page_id('shop');
    }
    if ( class_exists('Woocommerce') && (is_cart() ) ) {
        $post_id = woocommerce_get_page_id('cart');
    }
    if ( class_exists('Woocommerce') && (is_checkout() ) ) {
        $post_id = woocommerce_get_page_id('checkout');
    }

    if(!$post_id) {
    	if(isset($post->ID)) {
    		$post_id = $post->ID;
    	} else {
    		return null;
    	}
    }

	/* post ID null. */
	if(!$post_id && empty($post->ID)) return $default;
	
	/* get meta. */
	$meta = get_post_meta($post_id, $key, true);
	
	/* meta null. */
	if(empty($meta)) return $default;
	
	return $meta;
}

/**
 * Filter the page menu arguments.
 *
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 * @since 1.0.0
 */
function garden_page_menu_args( $args ) {
    if ( ! isset( $args['show_home'] ) )
        $args['show_home'] = true;
    return $args;
}

add_filter( 'wp_page_menu_args', 'garden_page_menu_args' );

/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since 1.0.0
 */
function garden_comment_nav() {
    // Are there comments to navigate through?


    if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
    ?>
	<nav class="navigation comment-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'wp-garden' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'wp-garden' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'wp-garden' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since 1.0.0
 */
function garden_paging_nav() {
    // Don't print empty markup if there's only one page.


	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
			'base'     => $pagenum_link,
			'format'   => $format,
			'total'    => $GLOBALS['wp_query']->max_num_pages,
			'current'  => $paged,
			'mid_size' => 1,
			'add_args' => array_map( 'urlencode', $query_args ),
			'prev_text' => '<i class="fa fa-angle-left"></i>',
			'next_text' => '<i class="fa fa-angle-right"></i>',
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation clearfix" role="navigation" >
			<div class="pagination loop-pagination">
				<?php echo ''.$links; ?>
			</div><!-- .pagination -->
	</nav><!-- .navigation -->
	<?php
	endif;
}
function garden_paging_nav_portfolio() {
    // Don't print empty markup if there's only one page.


	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
			'base'     => $pagenum_link,
			'format'   => $format,
			'total'    => $GLOBALS['wp_query']->max_num_pages,
			'current'  => $paged,
			'mid_size' => 1,
			'add_args' => array_map( 'urlencode', $query_args ),
			'prev_text' => '<i class="fa fa-angle-left"></i>',
			'next_text' => '<i class="fa fa-angle-right"></i>',
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation_portfolio clearfix" role="navigation" >
			<div class="pagination loop-pagination">
				<?php echo ''.$links; ?>
			</div><!-- .pagination -->
	</nav><!-- .navigation -->
	<?php
	endif;
}

// add font google font
add_filter('vc_google_fonts_get_fonts_filter', 'garden_add_google_font');
//font list is array
function garden_add_google_font($fonts_list){
	$shadows->font_family = 'Shadows Into Light';
	$shadows->font_types = '400 regular:400:normal, 700 bold regular:700:normal';
	$shadows->font_styles = 'regular';
	$shadows->font_style_description = 'Choose your font style you want';
	$shadows->font_family_description = 'Choose your font name you want';
	
	$fonts_list[] = $shadows;

	return $fonts_list;
}

/**
* Display navigation to next/previous post when applicable.
*
* @since 1.0.0
*/
function garden_post_nav() {


    global $post,$smof_data;

    $check = '';

    if($smof_data['pagingnav_blog'] == 1 ){ 
    	$check='';
	}else{  
		$check='none;';
	}

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation" role="navigation" style="display:<?php echo esc_attr($check);?>">
		<div class="nav-links clearfix ">
			<?php

			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="btn btn-default post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-angle-left"></i><?php echo esc_attr($prev_post->post_title); ?></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="btn btn-default post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><?php echo get_the_title( $next_post->ID ); ?><i class="fa fa-angle-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}


function garden_post_nav_portfolio() {


    global $post,$smof_data;

    $check = '';

    if($smof_data['pagingnav_blog'] == 1 ){ 
    	$check='';
	}else{  
		$check='none;';
	}

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation" role="navigation" style="display:<?php echo esc_attr($check);?>">
		<div class="nav-links clearfix ">
			<?php

			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="btn btn-default post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-angle-left"></i></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="btn btn-default post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><i class="fa fa-angle-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
function garden_post_nav_single_portfolio() {


    global $post,$smof_data;


    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation" role="navigation">
		<div class="nav-links clearfix ">
			<?php

			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="btn btn-default post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-angle-left"></i></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="btn btn-default post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><i class="fa fa-angle-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}

/* Add Custom Comment */
function garden_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
    ?>
    <<?php echo esc_attr($tag) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-body clearfix">
    <?php endif; ?>
    <div class="comment-author-image vcard">
    	<div class="avatar-author">
    		<?php echo get_avatar( $comment, 109 ); ?>
    	</div>
    	<div class="comment-meta commentmetadata">
    		<div class="top-commnet">
    			<span class="comment-author"><?php echo get_comment_author_link(); ?></span>
    			<div class="reply">
		    		<span></span><?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		    	</div>
    		</div>
    		<div class="comment-date">
    		<?php echo get_the_date("d M Y"); ?>
    		</div>
    		<?php if ( $comment->comment_approved == '0' ) : ?>
		    	<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.' , 'wp-garden'); ?></em>
		    <?php endif; ?>
		    <div class="comment-main">
		    	<div class="comment-content">
		    		<?php comment_text(); ?>
		    	</div>
		    </div>
		    <?php if ( 'div' != $args['style'] ) : ?>
		    </div>
		    <?php endif; ?>
    	</div>
    </div>
    
    <?php
}

/**
 * limit words
 * 
 * @since 1.0.0
 */
if (!function_exists('garden_limit_words')) {
    function garden_limit_words($string, $word_limit) {
        $words = explode(' ', $string, ($word_limit + 1));
        if (count($words) > $word_limit) {
            array_pop($words);
        }
        return implode(' ', $words)."";
    }
}

/**
 * Set home page.
 * 
 * get home title and update options.
 * 
 * @return Home page title.
 * @author FOX
 */
function garden_set_home_page(){
    
    $home_page = 'Default Version';
    
    $page = get_page_by_title($home_page);
    
    if(!isset($page->ID))
        return ;
    	
    update_option('show_on_front', 'page');
    update_option('page_on_front', $page->ID);
}

add_action('import_end', 'garden_set_home_page');

/**
 * Set menu locations.
 * 
 * get locations and menu name and update options.
 * 
 * @return string[]
 * @author FOX
 */
function garden_set_menu_location(){
    
    $setting = array(
        'Footer Menu' => 'menu-footer',
        'Primary Menu' => 'primary'
    );
    
    $navs = wp_get_nav_menus();
    
    $new_setting = array();
    
    foreach ($navs as $nav){
        
        if(!isset($setting[$nav->name]))
            continue;
        
        $id = $nav->term_id;
        $location = $setting[$nav->name];
        
        $new_setting[$location] = $id;
    }
    
    set_theme_mod('nav_menu_locations', $new_setting);
}

add_action('import_end', 'garden_set_menu_location');

function wp_futura_shortcode_change_rel($src) {
	if(strstr($src,'wp_futura/assets/css/') || strstr($src,'wp_futura/assets/css/') || strstr($src,'cmssuperheroes/assets/css/Pe-icon-7-stroke.css') || strstr($src,'cmssuperheroes/assets/css/bootstrap-progressbar.min.css') || strstr($src,'assets/lib/bower/font-awesome/css/font-awesome.min.css') || strstr($src,'js/mediaelement/')){
	
		return str_replace('rel', 'property="cms-stylesheet" rel', $src);
	}
	else{
		return $src;
	}
}
add_filter('style_loader_tag', 'wp_futura_shortcode_change_rel');

/* Import map */
function garden_add_map_js(){
    wp_enqueue_script('max-import-map', get_template_directory_uri() . '/assets/js/import-map.js', array( 'jquery' ), '1.0.0', true);
}
add_action( 'admin_enqueue_scripts', 'garden_add_map_js' );
/* AJAX HANDLER */
add_action('wp_ajax_max_import_map', 'garden_import_map_callback');
add_action('wp_ajax_nopriv_max_import_map', 'garden_import_map_callback');

function garden_import_map_callback(){
    $request = wp_remote_get(get_template_directory_uri() . '/inc/dummy/garden/maps_backup.json');
    $file = wp_remote_retrieve_body( $request );

	$options = get_option('mymaps_options');
	if( $file_content =  json_decode($file, true ) ) {

		/* Decode and redefine */
		try {
			$_HOST_             = $file_content['_host_'];
			$_MY_STYLES_        = (isset($file_content['_mystyles_']) && $file_content['_mystyles_'] != '' ) ? json_decode(rawurldecode($file_content['_mystyles_']), true) : '';
			$_MAP_POST_         = (isset($file_content['_map_posts_']) && $file_content['_map_posts_'] != '' ) ? json_decode(rawurldecode($file_content['_map_posts_']), true) : '';
			$_ICONS_            = (isset($file_content['_icons_']) && $file_content['_icons_'] != '' ) ? json_decode(rawurldecode($file_content['_icons_']), true) : '';
		} catch(Exception $e ) {
			echo 'content_incorrect'; exit();
		}

		/* check style */
		if( is_array($_MY_STYLES_) && count($_MY_STYLES_) > 0 )
		{
			foreach( $_MY_STYLES_  as $name => $value ) {
				if( !array_key_exists( $name, $options['_mystyles_'] ) )
				{
					$options['_mystyles_'][$name] = $value;
				}
			}
		}

		/* check icon */
		if( is_array($_ICONS_) && count($_ICONS_) > 0 )
		{
			foreach( $_ICONS_ as $value ) {
				if( !in_array( $value, $options['_icons_'] ) )
				{
					$options['_icons_'][] = $value;
				}
			}
		}
		/* check post */
		$options['_map_posts_'] = array();

		$cur_content_dir = (function_exists('content_url')) ? content_url() : plugins_url('.../.../',__FILE__);
		if( is_array($_MAP_POST_) && count($_MAP_POST_) > 0 )
		{
			foreach( $_MAP_POST_ as $value ) {
				try{
					$value['markers'] = str_replace($_HOST_, $cur_content_dir, $value['markers']);
				} catch( Exception $e ){
					echo 'fail';
					exit();
				}
				$options['_map_posts_'][] = $value;
			}
		}
		/* update */
		if( update_option( 'mymaps_options', $options ) ) {
			echo 'success';
		} else {
			echo 'nothing_change';
		}
	} else {
		echo 'content_incorrect';
	}
}
?>