<?php

/**
 * Auto create .css file from Theme Options
 * @author Fox
 * @version 1.0.0
 */
class CMSSuperHeroes_StaticCss
{

    public $scss;
    
    function __construct()
    {   
        /* scss */
        $this->scss = new scssc();
        
        /* set paths scss */
        $this->scss->setImportPaths(get_template_directory() . '/assets/scss/');
             
        /* generate css over time */
		add_action('init', array($this, 'generate_over_time'));
        
        /* save option generate css */
       	add_action("redux/options/smof_data/saved", array(
            $this,
            'generate_file'
        ));
    }
	
    public function generate_over_time(){
    	
    	global $smof_data;
    	
    	if (!isset($smof_data['dev_mode'])) return ;
    	
    	if (!$smof_data['dev_mode']) return ;
    		
    	$this->generate_file();
    }
    /**
     * generate css file.
     *
     * @since 1.0.0
     */
    public function generate_file()
    {
        global $smof_data, $wp_filesystem;
        
        if (! empty($smof_data) && ! empty($wp_filesystem)) {
            
        	$options_scss = get_template_directory() . '/assets/scss/options.scss';
        	
        	/* delete files options.scss */
        	$wp_filesystem->delete($options_scss);
        	
            /* write options to scss file */
            $wp_filesystem->put_contents($options_scss, $this->css_render(), FS_CHMOD_FILE); // Save it
            
            /* minimize CSS styles */
            if (!$smof_data['dev_mode']) {
                $this->scss->setFormatter('scss_formatter_compressed');
            }
            
            /* compile scss to css */
            $css = $this->scss_render();
            
            $file = "static.css";
            
            if(!empty($smof_data['presets_color']) && $smof_data['presets_color']){
                $file = "presets-".$smof_data['presets_color'].".css";
            }
            
            $file = get_template_directory() . '/assets/css/' . $file;
            
            /* delete files static.css */
            $wp_filesystem->delete($file);
            
            /* write static.css file */
            $wp_filesystem->put_contents($file, $css, FS_CHMOD_FILE); // Save it
        }
    }
    
    /**
     * scss compile
     * 
     * @since 1.0.0
     * @return string
     */
    public function scss_render(){
        /* compile scss to css */
        return $this->scss->compile('@import "master.scss"');
    }

    //$m = get_template_directory().'/assets/images/maintenance.png';
    
    /**
     * main css
     *
     * @since 1.0.0
     * @return string
     */
    public function css_render()
    {
        global $smof_data, $garden_base;
        
        ob_start();
        
        /* google fonts. */
        if(isset($smof_data['google-font-1'])){
            $garden_base->setGoogleFont($smof_data['google-font-1'], $smof_data['google-font-selector-1']);
        }
        if(isset($smof_data['google-font-2'])){
            $garden_base->setGoogleFont($smof_data['google-font-2'], $smof_data['google-font-selector-2']);
        }
        /* forward options to scss. */
        
        if(!empty($smof_data['primary_color'])){
            echo '$primary_color:'.esc_attr($smof_data['primary_color']).';';
        }
        if(!empty($smof_data['secondary_color'])){
            echo '$secondary_color:'.esc_attr($smof_data['secondary_color']).';';
        }
        if(!empty($smof_data['link_color_hover'])){
            echo '$link_color_hover:'.esc_attr($smof_data['link_color_hover']).';';
        }
        if($smof_data['header_color_top_footer']){
            echo '$header_color_top_footer:'.esc_attr($smof_data['header_color_top_footer']).';';
        }
        if($smof_data['content_color_top_footer']){
            echo '$content_color_top_footer:'.esc_attr($smof_data['content_color_top_footer']).';';
        }
        if($smof_data['link_color_top_footer']){
            echo '$link_color_top_footer:'.esc_attr($smof_data['link_color_top_footer']).';';
        }
        if($smof_data['content_color_bottom_footer']){
            echo '$content_color_bottom_footer:'.esc_attr($smof_data['content_color_bottom_footer']).';';
        }
        if($smof_data['color_bottom_border']){
            echo '$color_bottom_border:'.esc_attr($smof_data['color_bottom_border']).';';
        }
        if($smof_data['link_color_bottom_footer']){
            echo '$link_color_bottom_footer:'.esc_attr($smof_data['link_color_bottom_footer']).';';
        }
        if($smof_data['logo_height']['height']){
             echo '$logo_height:'.esc_attr($smof_data['logo_height']['height']).';';
        }
        if($smof_data['link_color']){
            echo '$link_color:'.esc_attr($smof_data['link_color']).';';
        }
        
        return ob_get_clean();
    }
}

new CMSSuperHeroes_StaticCss();